@@ -1811,10 +1811,6 @@ static Image *ReadDDSImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
   }
 
-  if (EOFBlob(image) != MagickFalse)
-    ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
-      image->filename);
-
   (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
@@ -2642,13 +2638,13 @@ static MagickBooleanType WriteDDSImage(const ImageInfo *image_info,
   if (pixelFormat == DDPF_FOURCC)
     {
       option=GetImageOption(image_info,"dds:cluster-fit");
-      if (option != (char *) NULL && LocaleCompare(option,"true") == 0)
+      if (IsStringTrue(option) != MagickFalse)
         {
           clusterFit=MagickTrue;
           if (compression != FOURCC_DXT1)
             {
               option=GetImageOption(image_info,"dds:weight-by-alpha");
-              if (option != (char *) NULL && LocaleCompare(option,"true") == 0)
+              if (IsStringTrue(option) != MagickFalse)
                 weightByAlpha=MagickTrue;
             }
         }
@@ -2733,7 +2729,7 @@ static void WriteDDSInfo(Image *image, const size_t pixelFormat,
   (void) WriteBlobLSBLong(image,0x00);
   (void) WriteBlobLSBLong(image,(unsigned int) mipmaps+1);
   (void) ResetMagickMemory(software,0,sizeof(software));
-  (void) strcpy(software,"IMAGEMAGICK");
+  (void) CopyMagickString(software,"IMAGEMAGICK",MaxTextExtent);
   (void) WriteBlob(image,44,(unsigned char *) software);
 
   (void) WriteBlobLSBLong(image,32);
