@@ -16,7 +16,7 @@
 %                                 July 2012                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2014 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -267,7 +267,11 @@ static Image *ReadJNXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       (void) ReadBlobLSBShort(image); /* height */
       tile_length=ReadBlobLSBLong(image);
       tile_offset=(int) ReadBlobLSBLong(image);
+      if (tile_offset == -1)
+        continue;
       restore_offset=TellBlob(image);
+      if (restore_offset < 0)
+        continue;
       offset=SeekBlob(image,(MagickOffsetType) tile_offset,SEEK_SET);
       if (offset != (MagickOffsetType) tile_offset)
         continue;
@@ -297,7 +301,7 @@ static Image *ReadJNXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       tile_image=BlobToImage(read_info,blob,tile_length+2,exception);
       read_info=DestroyImageInfo(read_info);
       blob=(unsigned char *) RelinquishMagickMemory(blob);
-      offset=SeekBlob(image,restore_offset,SEEK_SET);
+      (void) SeekBlob(image,restore_offset,SEEK_SET);
       if (tile_image == (Image *) NULL)
         continue;
       (void) CopyMagickString(tile_image->magick,image->magick,MaxTextExtent);
