@@ -18,7 +18,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2014 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -156,6 +156,12 @@ static Image *ReadMACImage(const ImageInfo *image_info,ExceptionInfo *exception)
       (void) CloseBlob(image);
       return(GetFirstImageInList(image));
     }
+  status=SetImageExtent(image,image->columns,image->rows);
+  if (status == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   /*
     Convert MAC raster image to pixel packets.
   */
@@ -192,8 +198,7 @@ static Image *ReadMACImage(const ImageInfo *image_info,ExceptionInfo *exception)
               {
                 if (bit == 0)
                   byte=(*p++);
-                SetPixelIndex(indexes+x,((byte & 0x80) != 0 ?
-                  0x01 : 0x00));
+                SetPixelIndex(indexes+x,((byte & 0x80) != 0 ? 0x01 : 0x00));
                 bit++;
                 byte<<=1;
                 if (bit == 8)
@@ -228,8 +233,7 @@ static Image *ReadMACImage(const ImageInfo *image_info,ExceptionInfo *exception)
           {
             if (bit == 0)
               byte=(*p++);
-            SetPixelIndex(indexes+x,((byte & 0x80) != 0 ?
-              0x01 : 0x00));
+            SetPixelIndex(indexes+x,((byte & 0x80) != 0 ?  0x01 : 0x00));
             bit++;
             byte<<=1;
             if (bit == 8)
@@ -244,6 +248,7 @@ static Image *ReadMACImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
   }
   pixels=(unsigned char *) RelinquishMagickMemory(pixels);
+  (void) SyncImage(image);
   (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
