@@ -110,7 +110,7 @@ static Image *ReadMASKImage(const ImageInfo *image_info,
   assert(exception->signature == MagickSignature);
   read_info=CloneImageInfo(image_info);
   SetImageInfoBlob(read_info,(void *) NULL,0);
-  *read_info->magick='\0';
+  (void) CopyMagickString(read_info->magick,"MIFF",MaxTextExtent);
   image=ReadImage(read_info,exception);
   read_info=DestroyImageInfo(read_info);
   if (image != (Image *) NULL)
