@@ -382,10 +382,10 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
   char
     command[MaxTextExtent],
-    density[MaxTextExtent],
+    *density,
     filename[MaxTextExtent],
     geometry[MaxTextExtent],
-    options[MaxTextExtent],
+    *options,
     input_filename[MaxTextExtent],
     message[MaxTextExtent],
     postscript_filename[MaxTextExtent];
@@ -418,8 +418,9 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     cmyk,
     cropbox,
     fitPage,
-    trimbox,
-    status;
+    status,
+    stop_on_error,
+    trimbox;
 
   MagickStatusType
     flags;
@@ -509,6 +510,10 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   option=GetImageOption(image_info,"pdf:use-cropbox");
   if (option != (const char *) NULL)
     cropbox=IsMagickTrue(option);
+  stop_on_error=MagickFalse;
+  option=GetImageOption(image_info,"pdf:stop-on-error");
+  if (option != (const char *) NULL)
+    stop_on_error=IsMagickTrue(option);
   trimbox=MagickFalse;
   option=GetImageOption(image_info,"pdf:use-trimbox");
   if (option != (const char *) NULL)
@@ -535,7 +540,7 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *(--p)='\0';
     p=command;
     if (LocaleNCompare(PDFRotate,command,strlen(PDFRotate)) == 0)
-      count=(ssize_t) sscanf(command,"Rotate %lf",&angle);
+      (void) sscanf(command,"Rotate %lf",&angle);
     /*
       Is this a CMYK document?
     */
@@ -710,7 +715,8 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image=DestroyImage(image);
       return((Image *) NULL);
     }
-  *options='\0';
+  density=AcquireString("");
+  options=AcquireString("");
   (void) FormatLocaleString(density,MaxTextExtent,"%gx%g",image->x_resolution,
     image->y_resolution);
   if ((image_info->page != (char *) NULL) || (fitPage != MagickFalse))
@@ -724,6 +730,8 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     (void) ConcatenateMagickString(options,"-dUseCropBox ",MaxTextExtent);
   if (trimbox != MagickFalse)
     (void) ConcatenateMagickString(options,"-dUseTrimBox ",MaxTextExtent);
+  if (stop_on_error != MagickFalse)
+    (void) ConcatenateMagickString(options,"-dPDFSTOPONERROR ",MaxTextExtent);
   read_info=CloneImageInfo(image_info);
   *read_info->magick='\0';
   if (read_info->number_scenes != 0)
@@ -751,6 +759,8 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     read_info->antialias != MagickFalse ? 4 : 1,
     read_info->antialias != MagickFalse ? 4 : 1,density,options,filename,
     postscript_filename,input_filename);
+  options=DestroyString(options);
+  density=DestroyString(density);
   *message='\0';
   status=InvokePDFDelegate(read_info->verbose,command,message,exception);
   (void) RelinquishUniqueFileResource(postscript_filename);
@@ -1323,7 +1333,7 @@ RestoreMSCWarning
       case FaxCompression:
       case Group4Compression:
       {
-        if ((IsMonochromeImage(image,&image->exception) == MagickFalse) ||
+        if ((SetImageMonochrome(image,&image->exception) == MagickFalse) ||
             (image->matte != MagickFalse))
           compression=RLECompression;
         break;
@@ -1675,7 +1685,7 @@ RestoreMSCWarning
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     if ((compression == FaxCompression) || (compression == Group4Compression) ||
         ((image_info->type != TrueColorType) &&
-         (IsGrayImage(image,&image->exception) != MagickFalse)))
+         (SetImageGray(image,&image->exception) != MagickFalse)))
       {
         switch (compression)
         {
@@ -2023,7 +2033,7 @@ RestoreMSCWarning
       if ((compression == FaxCompression) ||
           (compression == Group4Compression) ||
           ((image_info->type != TrueColorType) &&
-           (IsGrayImage(image,&image->exception) != MagickFalse)))
+           (SetImageGray(image,&image->exception) != MagickFalse)))
           (void) CopyMagickString(buffer,"/DeviceGray\n",MaxTextExtent);
       else
         if ((image->storage_class == DirectClass) || (image->colors > 256) ||
@@ -2130,7 +2140,7 @@ RestoreMSCWarning
     if ((compression == FaxCompression) ||
         (compression == Group4Compression) ||
         ((image_info->type != TrueColorType) &&
-         (IsGrayImage(tile_image,&image->exception) != MagickFalse)))
+         (SetImageGray(tile_image,&image->exception) != MagickFalse)))
       {
         switch (compression)
         {
