@@ -247,14 +247,10 @@ static Image *ReadTGAImage(const ImageInfo *image_info,
   if ((tga_info.image_type != TGAColormap) &&
       (tga_info.image_type != TGARLEColormap))
     image->depth=(size_t) ((tga_info.bits_per_pixel <= 8) ? 8 :
-      (tga_info.bits_per_pixel <= 16) ? 5 :
-      (tga_info.bits_per_pixel == 24) ? 8 :
-      (tga_info.bits_per_pixel == 32) ? 8 : 8);
+      (tga_info.bits_per_pixel <= 16) ? 5 : 8);
   else
     image->depth=(size_t) ((tga_info.colormap_size <= 8) ? 8 :
-      (tga_info.colormap_size <= 16) ? 5 :
-      (tga_info.colormap_size == 24) ? 8 :
-      (tga_info.colormap_size == 32) ? 8 : 8);
+      (tga_info.colormap_size <= 16) ? 5 : 8);
   if ((tga_info.image_type == TGAColormap) ||
       (tga_info.image_type == TGAMonochrome) ||
       (tga_info.image_type == TGARLEColormap) ||
@@ -298,7 +294,7 @@ static Image *ReadTGAImage(const ImageInfo *image_info,
           sizeof(*comment));
       if (comment == (char *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-      count=ReadBlob(image,tga_info.id_length,(unsigned char *) comment);
+      (void) ReadBlob(image,tga_info.id_length,(unsigned char *) comment);
       comment[tga_info.id_length]='\0';
       (void) SetImageProperty(image,"comment",comment);
       comment=DestroyString(comment);
@@ -509,9 +505,11 @@ static Image *ReadTGAImage(const ImageInfo *image_info,
         SetPixelOpacity(q,pixel.opacity);
       q++;
     }
-    if (((unsigned char) (tga_info.attributes & 0xc0) >> 6) == 4)
-      offset+=4;
-    else
+    /*
+      if (((unsigned char) (tga_info.attributes & 0xc0) >> 6) == 4)
+        offset+=4;
+      else
+    */
       if (((unsigned char) (tga_info.attributes & 0xc0) >> 6) == 2)
         offset+=2;
       else
