@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2014 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -146,6 +146,12 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image=AcquireImage(image_info);
   if ((image->columns == 0) || (image->rows == 0))
     ThrowReaderException(OptionError,"MustSpecifyImageSize");
+  status=SetImageExtent(image,image->columns,image->rows);
+  if (status == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   quantum=(size_t) (image->depth <= 8 ? 1 : 2);
   interlace=image_info->interlace;
   horizontal_factor=2;
@@ -196,7 +202,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
     scanline=(unsigned char *) AcquireQuantumMemory((size_t) 2UL*
       image->columns+2UL,quantum*sizeof(*scanline));
   else
-    scanline=(unsigned char *) AcquireQuantumMemory((size_t) image->columns,
+    scanline=(unsigned char *) AcquireQuantumMemory(image->columns,
       quantum*sizeof(*scanline));
   if (scanline == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -213,6 +219,12 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+    status=SetImageExtent(image,image->columns,image->rows);
+    if (status == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     if (interlace == PartitionInterlace)
       {
         AppendImageFormat("Y",image->filename);
@@ -231,7 +243,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if (interlace == NoInterlace)
         {
           if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
-            count=ReadBlob(image,(size_t) (2*quantum*image->columns),scanline);
+            (void) ReadBlob(image,(size_t) (2*quantum*image->columns),scanline);
           p=scanline;
           q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
           if (q == (PixelPacket *) NULL)
@@ -285,7 +297,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       else
         {
           if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
-            count=ReadBlob(image,(size_t) quantum*image->columns,scanline);
+            (void) ReadBlob(image,(size_t) quantum*image->columns,scanline);
           p=scanline;
           q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
           if (q == (PixelPacket *) NULL)
@@ -332,7 +344,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       {
         for (y=0; y < (ssize_t) chroma_image->rows; y++)
         {
-          count=ReadBlob(image,(size_t) quantum*chroma_image->columns,scanline);
+          (void) ReadBlob(image,(size_t) quantum*chroma_image->columns,scanline);
           p=scanline;
           q=QueueAuthenticPixels(chroma_image,0,y,chroma_image->columns,1,
             exception);
@@ -367,7 +379,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
       for (y=0; y < (ssize_t) chroma_image->rows; y++)
       {
-        count=ReadBlob(image,(size_t) quantum*chroma_image->columns,scanline);
+        (void) ReadBlob(image,(size_t) quantum*chroma_image->columns,scanline);
         p=scanline;
         q=GetAuthenticPixels(chroma_image,0,y,chroma_image->columns,1,
           exception);
@@ -672,13 +684,10 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
               {
                 (void) WriteBlobByte(image,ScaleQuantumToChar(
                   GetPixelGreen(s)));
-                (void) WriteBlobByte(image,ScaleQuantumToChar(
-                  GetPixelRed(p)));
+                (void) WriteBlobByte(image,ScaleQuantumToChar(GetPixelRed(p)));
                 p++;
-                (void) WriteBlobByte(image,ScaleQuantumToChar(
-                  GetPixelBlue(s)));
-                (void) WriteBlobByte(image,ScaleQuantumToChar(
-                  GetPixelRed(p)));
+                (void) WriteBlobByte(image,ScaleQuantumToChar(GetPixelBlue(s)));
+                (void) WriteBlobByte(image,ScaleQuantumToChar(GetPixelRed(p)));
               }
             else
               {
@@ -687,8 +696,7 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
                 (void) WriteBlobShort(image,ScaleQuantumToShort(
                   GetPixelRed(p)));
                 p++;
-                (void) WriteBlobByte(image,ScaleQuantumToChar(
-                  GetPixelBlue(s)));
+                (void) WriteBlobByte(image,ScaleQuantumToChar(GetPixelBlue(s)));
                 (void) WriteBlobShort(image,ScaleQuantumToShort(
                   GetPixelRed(p)));
               }
@@ -720,11 +728,9 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
           for (x=0; x < (ssize_t) yuv_image->columns; x++)
           {
             if (quantum == 1)
-              (void) WriteBlobByte(image,ScaleQuantumToChar(
-                GetPixelRed(p)));
+              (void) WriteBlobByte(image,ScaleQuantumToChar(GetPixelRed(p)));
             else
-              (void) WriteBlobShort(image,ScaleQuantumToShort(
-                GetPixelRed(p)));
+              (void) WriteBlobShort(image,ScaleQuantumToShort(GetPixelRed(p)));
             p++;
           }
           if (image->previous == (Image *) NULL)
@@ -763,8 +769,7 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
           for (x=0; x < (ssize_t) chroma_image->columns; x++)
           {
             if (quantum == 1)
-              (void) WriteBlobByte(image,ScaleQuantumToChar(
-                GetPixelGreen(p)));
+              (void) WriteBlobByte(image,ScaleQuantumToChar(GetPixelGreen(p)));
             else
               (void) WriteBlobShort(image,ScaleQuantumToShort(
                 GetPixelGreen(p)));
@@ -798,11 +803,9 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
           for (x=0; x < (ssize_t) chroma_image->columns; x++)
           {
             if (quantum == 1)
-              (void) WriteBlobByte(image,ScaleQuantumToChar(
-                GetPixelBlue(p)));
+              (void) WriteBlobByte(image,ScaleQuantumToChar(GetPixelBlue(p)));
             else
-              (void) WriteBlobShort(image,ScaleQuantumToShort(
-                GetPixelBlue(p)));
+              (void) WriteBlobShort(image,ScaleQuantumToShort(GetPixelBlue(p)));
             p++;
           }
         }
