@@ -97,16 +97,20 @@ static const CoderMapInfo
     { "B", "RAW" },
     { "BRF", "BRAILLE" },
     { "BGRA", "BGR" },
+    { "BGRO", "BGR" },
     { "CMYKA", "CMYK" },
     { "C", "RAW" },
     { "CAL", "CALS" },
     { "CANVAS", "XC" },
+    { "CMYKA", "CMYK" },
     { "CR2", "DNG" },
     { "CRW", "DNG" },
     { "CUR", "ICON" },
     { "DCR", "DNG" },
     { "DCX", "PCX" },
     { "DFONT", "TTF" },
+    { "DXT1", "DDS" },
+    { "DXT5", "DDS" },
     { "EPDF", "PDF" },
     { "EPI", "PS" },
     { "EPS2", "PS2" },
@@ -128,6 +132,9 @@ static const CoderMapInfo
     { "GRANITE", "MAGICK" },
     { "GROUP4", "TIFF" },
     { "GV", "DOT" },
+    { "HTM", "HTML" },
+    { "ICB", "TGA" },
+    { "ICO", "ICON" },
     { "IIQ", "DNG" },
     { "K25", "DNG" },
     { "KDC", "DNG" },
@@ -151,15 +158,22 @@ static const CoderMapInfo
     { "JPM", "JP2" },
     { "J2C", "JP2" },
     { "J2K", "JP2" },
+    { "JNG", "PNG" },
     { "JPE", "JPEG" },
     { "JPG", "JPEG" },
+    { "JPM", "JP2" },
     { "JPS", "JPEG" },
+    { "JPT", "JP2" },
     { "JPX", "JP2" },
     { "K", "RAW" },
+    { "K25", "DNG" },
+    { "KDC", "DNG" },
     { "LOGO", "MAGICK" },
+    { "M", "RAW" },
     { "M2V", "MPEG" },
     { "M4V", "MPEG" },
-    { "M", "RAW" },
+    { "MEF", "DNG" },
+    { "MKV", "MPEG" },
     { "MNG", "PNG" },
     { "MOV", "MPEG" },
     { "MP4", "MPEG" },
@@ -179,6 +193,7 @@ static const CoderMapInfo
     { "PAM", "PNM" },
     { "PBM", "PNM" },
     { "PCDS", "PCD" },
+    { "PCT", "PICT" },
     { "PDFA", "PDF" },
     { "PEF", "DNG" },
     { "PEF", "DNG" },
@@ -190,12 +205,16 @@ static const CoderMapInfo
     { "PICON", "XPM" },
     { "PJPEG", "JPEG" },
     { "PM", "XPM" },
+    { "PNG00", "PNG" },
     { "PNG24", "PNG" },
     { "PNG32", "PNG" },
+    { "PNG48", "PNG" },
+    { "PNG64", "PNG" },
     { "PNG8", "PNG" },
     { "PPM", "PNM" },
     { "PSB", "PSD" },
     { "PTIF", "TIFF" },
+    { "R", "RAW" },
     { "RADIAL-GRADIENT", "GRADIENT" },
     { "RAF", "DNG" },
     { "RAS", "SUN" },
@@ -203,7 +222,6 @@ static const CoderMapInfo
     { "RGBA", "RGB" },
     { "RGBO", "RGB" },
     { "RMF", "DNG" },
-    { "R", "RAW" },
     { "ROSE", "MAGICK" },
     { "RW2", "DNG" },
     { "SHTML", "HTML" },
