@@ -44,35 +44,28 @@ static inline MagickRealType MagickOver_(const MagickRealType p,
 
   Sa=1.0-QuantumScale*alpha;
   Da=1.0-QuantumScale*beta;
-  return(QuantumRange*(QuantumScale*Sa*p+QuantumScale*Da*q*(1.0-Sa)));
+  return(Sa*p+Da*q*(1.0-Sa));
 }
 
 static inline void MagickCompositeOver(const PixelPacket *p,
   const MagickRealType alpha,const PixelPacket *q,const MagickRealType beta,
   PixelPacket *composite)
 {
-  double
-    gamma;
-
   MagickRealType
     Da,
+    gamma,
     Sa;
 
   /*
     Compose pixel p over pixel q with the given opacities.
   */
-  if (fabs((double) (alpha-TransparentOpacity)) < MagickEpsilon)
-    { 
-      *composite=(*q);
-      return;
-    }
   Sa=1.0-QuantumScale*alpha;
   Da=1.0-QuantumScale*beta;
-  gamma=Sa*(-Da)+Sa+Da;
-  gamma=PerceptibleReciprocal(gamma);
+  gamma=Sa+Da-Sa*Da;
 #if !defined(MAGICKCORE_HDRI_SUPPORT)
-  SetPixelOpacity(composite,(MagickRealType) (QuantumRange*
-    (1.0-RoundToUnity(Sa+Da-Sa*Da))+0.5));
+  SetPixelOpacity(composite,ClampToQuantum(QuantumRange*(1.0-
+    RoundToUnity(gamma))));
+  gamma=PerceptibleReciprocal(gamma);
   SetPixelRed(composite,ClampToQuantum(gamma*MagickOver_((MagickRealType)
     GetPixelRed(p),alpha,(MagickRealType) GetPixelRed(q),beta)));
   SetPixelGreen(composite,ClampToQuantum(gamma*MagickOver_((MagickRealType)
@@ -80,7 +73,8 @@ static inline void MagickCompositeOver(const PixelPacket *p,
   SetPixelBlue(composite,ClampToQuantum(gamma*MagickOver_((MagickRealType)
     GetPixelBlue(p),alpha,(MagickRealType) GetPixelBlue(q),beta)));
 #else
-  SetPixelOpacity(composite,QuantumRange*(1.0-RoundToUnity(Sa+Da-Sa*Da)));
+  SetPixelOpacity(composite,QuantumRange*(1.0-RoundToUnity(gamma)));
+  gamma=PerceptibleReciprocal(gamma);
   SetPixelRed(composite,gamma*MagickOver_((MagickRealType)
     GetPixelRed(p),alpha,(MagickRealType) GetPixelRed(q),beta));
   SetPixelGreen(composite,gamma*MagickOver_((MagickRealType)
@@ -94,11 +88,9 @@ static inline void MagickPixelCompositeOver(const MagickPixelPacket *p,
   const MagickRealType alpha,const MagickPixelPacket *q,
   const MagickRealType beta,MagickPixelPacket *composite)
 {
-  double
-    gamma;
-
   MagickRealType
     Da,
+    gamma,
     Sa;
 
   /*
@@ -106,10 +98,9 @@ static inline void MagickPixelCompositeOver(const MagickPixelPacket *p,
   */
   Sa=1.0-QuantumScale*alpha;
   Da=1.0-QuantumScale*beta;
-  gamma=Sa*(-Da)+Sa+Da;
+  gamma=Sa+Da-Sa*Da;
+  composite->opacity=(MagickRealType) (QuantumRange*(1.0-RoundToUnity(gamma)));
   gamma=PerceptibleReciprocal(gamma);
-  composite->opacity=(MagickRealType) (QuantumRange*(1.0-
-    RoundToUnity(Sa+Da-Sa*Da)));
   composite->red=gamma*MagickOver_(p->red,alpha,q->red,beta);
   composite->green=gamma*MagickOver_(p->green,alpha,q->green,beta);
   composite->blue=gamma*MagickOver_(p->blue,alpha,q->blue,beta);
@@ -121,11 +112,9 @@ static inline void MagickPixelCompositePlus(const MagickPixelPacket *p,
   const MagickRealType alpha,const MagickPixelPacket *q,
   const MagickRealType beta,MagickPixelPacket *composite)
 {
-  double
-    gamma;
-
   MagickRealType
     Da,
+    gamma,
     Sa;
 
   /*
@@ -134,7 +123,7 @@ static inline void MagickPixelCompositePlus(const MagickPixelPacket *p,
   Sa=1.0-QuantumScale*alpha;
   Da=1.0-QuantumScale*beta;
   gamma=RoundToUnity(Sa+Da);  /* 'Plus' blending -- not 'Over' blending */
-  composite->opacity=(MagickRealType) QuantumRange*(1.0-gamma);
+  composite->opacity=(MagickRealType) QuantumRange*(1.0-RoundToUnity(gamma));
   gamma=PerceptibleReciprocal(gamma);
   composite->red=gamma*(Sa*p->red+Da*q->red);
   composite->green=gamma*(Sa*p->green+Da*q->green);
