@@ -19,7 +19,7 @@
 %                                 July 2009                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2014 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -44,6 +44,7 @@
 */
 #include "magick/studio.h"
 #include "magick/artifact.h"
+#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/cache.h"
 #include "magick/image.h"
@@ -114,8 +115,8 @@ typedef struct _FourierInfo
 %
 %  The format of the ComplexImages method is:
 %
-%      MagickBooleanType ComplexImages(Image *images,
-%        const ComplexOperator op,ExceptionInfo *exception)
+%      MagickBooleanType ComplexImages(Image *images,const ComplexOperator op,
+%        ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
@@ -191,9 +192,9 @@ MagickExport Image *ComplexImages(const Image *images,const ComplexOperator op,
       complex_images=DestroyImageList(complex_images);
       return(complex_images);
     }
-  image->storage_class=DirectClass;
-  image->depth=32UL;
   AppendImageToList(&complex_images,image);
+  complex_images->storage_class=DirectClass;
+  complex_images->depth=32UL;
   /*
     Apply complex mathematics to image pixels.
   */
@@ -222,8 +223,8 @@ MagickExport Image *ComplexImages(const Image *images,const ComplexOperator op,
   status=MagickTrue;
   progress=0;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-    #pragma omp parallel for schedule(static,4) shared(progress,status) \
-      magick_threads(images,complex_images,images->rows,1)
+  #pragma omp parallel for schedule(static,4) shared(progress,status) \
+    magick_threads(images,complex_images,images->rows,1)
 #endif
   for (y=0; y < (ssize_t) images->rows; y++)
   {
@@ -242,12 +243,12 @@ MagickExport Image *ComplexImages(const Image *images,const ComplexOperator op,
 
     if (status == MagickFalse)
       continue;
-    Ar=GetCacheViewVirtualPixels(Ar_view,0,y,images->columns,1,exception);
-    Ai=GetCacheViewVirtualPixels(Ai_view,0,y,images->columns,1,exception);
-    Br=GetCacheViewVirtualPixels(Br_view,0,y,images->columns,1,exception);
-    Bi=GetCacheViewVirtualPixels(Bi_view,0,y,images->columns,1,exception);
-    Cr=QueueCacheViewAuthenticPixels(Cr_view,0,y,images->columns,1,exception);
-    Ci=QueueCacheViewAuthenticPixels(Ci_view,0,y,images->columns,1,exception);
+    Ar=GetCacheViewVirtualPixels(Ar_view,0,y,Ar_image->columns,1,exception);
+    Ai=GetCacheViewVirtualPixels(Ai_view,0,y,Ai_image->columns,1,exception);
+    Br=GetCacheViewVirtualPixels(Br_view,0,y,Br_image->columns,1,exception);
+    Bi=GetCacheViewVirtualPixels(Bi_view,0,y,Bi_image->columns,1,exception);
+    Cr=QueueCacheViewAuthenticPixels(Cr_view,0,y,Cr_image->columns,1,exception);
+    Ci=QueueCacheViewAuthenticPixels(Ci_view,0,y,Ci_image->columns,1,exception);
     if ((Ar == (const PixelPacket *) NULL) ||
         (Ai == (const PixelPacket *) NULL) ||
         (Br == (const PixelPacket *) NULL) ||
