@@ -17,7 +17,7 @@
 %                              January 2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2014 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -45,6 +45,7 @@
 #include "magick/exception.h"
 #include "magick/exception-private.h"
 #include "magick/geometry.h"
+#include "magick/image-private.h"
 #include "magick/memory_.h"
 #include "magick/string_.h"
 #include "magick/string-private.h"
@@ -925,7 +926,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
         break;
       }
       default:
-        return(flags);
+        return(NoValue);
     }
   }
   /*
@@ -937,7 +938,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
   q=p;
   value=StringToDouble(p,&q);
   if (LocaleNCompare(p,"0x",2) == 0)
-    value=(double) strtol(p,&q,10);
+    (void) strtol(p,&q,10);
   c=(int) ((unsigned char) *q);
   if ((c == 215) || (*q == 'x') || (*q == 'X') || (*q == ',') ||
       (*q == '/') || (*q == ':') || (*q =='\0'))
@@ -990,17 +991,17 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
       if ((*p == ',') || (*p == '/') || (*p == ':') )
         p++;
       while ((*p == '+') || (*p == '-'))
-        {
-          if (*p == '-')
-            flags^=XiNegative;  /* negate sign */
-          p++;
-        }
+      {
+        if (*p == '-')
+          flags^=XiNegative;  /* negate sign */
+        p++;
+      }
       q=p;
       value=StringToDouble(p,&p);
       if (p != q)
         {
           flags|=XiValue;
-          if ((flags&XiNegative) != 0)
+          if ((flags & XiNegative) != 0)
             value=(-value);
           geometry_info->xi=value;
         }
@@ -1025,7 +1026,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
           if (p != q)
             {
               flags|=PsiValue;
-              if ((flags&PsiNegative) != 0)
+              if ((flags & PsiNegative) != 0)
                 value=(-value);
               geometry_info->psi=value;
             }
@@ -1051,7 +1052,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
           if (p != q)
             {
               flags|=ChiValue;
-              if ((flags&ChiNegative) != 0)
+              if ((flags & ChiNegative) != 0)
                 value=(-value);
               geometry_info->chi=value;
             }
@@ -1243,14 +1244,6 @@ MagickExport MagickStatusType ParseGravityGeometry(const Image *image,
 %
 */
 
-static inline size_t MagickMax(const size_t x,
-  const size_t y)
-{
-  if (x > y)
-    return(x);
-  return(y);
-}
-
 MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,ssize_t *x,
   ssize_t *y,size_t *width,size_t *height)
 {
@@ -1382,8 +1375,8 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,ssize_t *x,
       (void) ParseGeometry(geometry,&geometry_info);
       area=geometry_info.rho+sqrt(MagickEpsilon);
       distance=sqrt((double) former_width*former_height);
-      scale.x=former_width/(distance/sqrt(area));
-      scale.y=former_height/(distance/sqrt(area));
+      scale.x=(double) former_width/(distance/sqrt(area));
+      scale.y=(double) former_height/(distance/sqrt(area));
       if ((scale.x < (double) *width) || (scale.y < (double) *height))
         {
           *width=(unsigned long) (former_width/(distance/sqrt(area)));
