@@ -41,8 +41,7 @@ extern "C" {
 #define GetPixelCyan(pixel) ((pixel)->red)
 #define GetPixelGray(pixel) ((pixel)->red)
 #define GetPixelGreen(pixel) ((pixel)->green)
-#define GetPixelIndex(indexes) \
-  ((indexes == (const IndexPacket *) NULL) ? 0 : (*(indexes)))
+#define GetPixelIndex(indexes)  (*(indexes))
 #define GetPixelL(pixel) ((pixel)->red)
 #define GetPixelMagenta(pixel) ((pixel)->green)
 #define GetPixelNext(pixel)  ((pixel)+1)
@@ -75,15 +74,10 @@ extern "C" {
 #define SetPixelGray(pixel,value) \
   ((pixel)->red=(pixel)->green=(pixel)->blue=(Quantum) (value))
 #define SetPixelGreen(pixel,value) ((pixel)->green=(Quantum) (value))
-#define SetPixelIndex(indexes,value) \
-{ \
-  if (indexes != (IndexPacket *) NULL) \
-    (*(indexes)=(IndexPacket) (value)); \
-}
+#define SetPixelIndex(indexes,value) (*(indexes)=(IndexPacket) (value))
 #define SetPixelL(pixel,value) ((pixel)->red=(Quantum) (value))
 #define SetPixelMagenta(pixel,value) ((pixel)->green=(Quantum) (value))
-#define SetPixelOpacity(pixel,value) \
-  ((pixel)->opacity=(Quantum) (value))
+#define SetPixelOpacity(pixel,value) ((pixel)->opacity=(Quantum) (value))
 #define SetPixelRed(pixel,value) ((pixel)->red=(Quantum) (value))
 #define SetPixelRgb(pixel,packet) \
 { \
@@ -144,14 +138,10 @@ static inline MagickRealType GetPixelLuma(const Image *restrict image,
   const PixelPacket *restrict pixel)
 {
   MagickRealType
-    gamma,
     intensity;
 
-  gamma=1.0;
-  if (image->matte != MagickFalse)
-    gamma=PerceptibleReciprocal(QuantumScale*(QuantumRange-pixel->opacity));
-  intensity=0.212656f*gamma*pixel->red+0.715158f*gamma*pixel->green+
-    0.072186f*gamma*pixel->blue;
+  intensity=(MagickRealType) (0.212656f*pixel->red+0.715158f*pixel->green+
+    0.072186f*pixel->blue);
   return(intensity);
 }
 
@@ -159,21 +149,17 @@ static inline MagickRealType GetPixelLuminance(const Image *restrict image,
   const PixelPacket *restrict pixel)
 {
   MagickRealType
-    gamma,
     intensity;
 
-  gamma=1.0;
-  if (image->matte != MagickFalse)
-    gamma=PerceptibleReciprocal(QuantumScale*(QuantumRange-pixel->opacity));
   if (image->colorspace != sRGBColorspace)
     {
-      intensity=0.212656f*gamma*pixel->red+0.715158f*gamma*pixel->green+
-        0.072186f*gamma*pixel->blue;
+      intensity=(MagickRealType) (0.212656f*pixel->red+0.715158f*pixel->green+
+        0.072186f*pixel->blue);
       return(intensity);
     }
-  intensity=0.212656f*DecodePixelGamma(gamma*pixel->red)+
-    0.715158f*DecodePixelGamma(gamma*pixel->green)+
-    0.072186f*DecodePixelGamma(gamma*pixel->blue);
+  intensity=(MagickRealType) (0.212656f*DecodePixelGamma((MagickRealType)
+    pixel->red)+0.715158f*DecodePixelGamma((MagickRealType) pixel->green)+
+    0.072186f*DecodePixelGamma((MagickRealType) pixel->blue));
   return(intensity);
 }
 
@@ -214,7 +200,8 @@ static inline Quantum PixelPacketIntensity(const PixelPacket *pixel)
 
   if ((pixel->red  == pixel->green) && (pixel->green == pixel->blue))
     return(pixel->red);
-  intensity=0.212656*pixel->red+0.715158*pixel->green+0.072186*pixel->blue;
+  intensity=(MagickRealType) (0.212656*pixel->red+0.715158*pixel->green+
+    0.072186*pixel->blue);
   return(ClampToQuantum(intensity));
 }
 
