@@ -17,7 +17,7 @@
 %                                 May 2001                                    %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2014 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2015 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -47,6 +47,7 @@
 #include "magick/exception.h"
 #include "magick/exception-private.h"
 #include "magick/hashmap.h"
+#include "magick/image-private.h"
 #include "magick/log.h"
 #include "magick/memory_.h"
 #include "magick/nt-base-private.h"
@@ -329,20 +330,6 @@ MagickExport const TypeInfo *GetTypeInfo(const char *name,
 %
 */
 
-static inline size_t MagickMax(const size_t x,const size_t y)
-{
-  if (x > y)
-    return(x);
-  return(y);
-}
-
-static inline size_t MagickMin(const size_t x,const size_t y)
-{
-  if (x < y)
-    return(x);
-  return(y);
-}
-
 MagickExport const TypeInfo *GetTypeInfoByFamily(const char *family,
   const StyleType style,const StretchType stretch,const size_t weight,
   ExceptionInfo *exception)
@@ -380,6 +367,7 @@ MagickExport const TypeInfo *GetTypeInfoByFamily(const char *family,
     };
 
   size_t
+    font_weight,
     max_score,
     score;
 
@@ -389,6 +377,7 @@ MagickExport const TypeInfo *GetTypeInfoByFamily(const char *family,
   (void) GetTypeInfo("*",exception);
   if (type_cache == (SplayTreeInfo *) NULL)
     return((TypeInfo *) NULL);
+  font_weight=weight == 0 ? 400 : weight;
   LockSemaphoreInfo(type_semaphore);
   ResetSplayTreeIterator(type_cache);
   type_info=(const TypeInfo *) NULL;
@@ -426,7 +415,7 @@ MagickExport const TypeInfo *GetTypeInfoByFamily(const char *family,
         p=(const TypeInfo *) GetNextValueInSplayTree(type_cache);
         continue;
       }
-    if ((weight != 0) && (p->weight != weight))
+    if (p->weight != font_weight)
       {
         p=(const TypeInfo *) GetNextValueInSplayTree(type_cache);
         continue;
@@ -473,11 +462,8 @@ MagickExport const TypeInfo *GetTypeInfoByFamily(const char *family,
       if (((style == ItalicStyle) || (style == ObliqueStyle)) &&
           ((p->style == ItalicStyle) || (p->style == ObliqueStyle)))
         score+=25;
-    if (weight == 0)
-      score+=16;
-    else
-      score+=(16*(800-((ssize_t) MagickMax(MagickMin(weight,900),p->weight)-
-        (ssize_t) MagickMin(MagickMin(weight,900),p->weight))))/800;
+    score+=(16*(800-((ssize_t) MagickMax(MagickMin(font_weight,900),p->weight)-
+      (ssize_t) MagickMin(MagickMin(font_weight,900),p->weight))))/800;
     if ((stretch == UndefinedStretch) || (stretch == AnyStretch))
       score+=8;
     else
@@ -1090,7 +1076,7 @@ static MagickBooleanType LoadTypeCache(SplayTreeInfo *type_cache,
   const char
     *q;
 
-  MagickBooleanType
+  MagickStatusType
     status;
 
   TypeInfo
@@ -1322,11 +1308,13 @@ static MagickBooleanType LoadTypeCache(SplayTreeInfo *type_cache,
       {
         if (LocaleCompare((char *) keyword,"weight") == 0)
           {
-            type_info->weight=StringToUnsignedLong(token);
-            if (LocaleCompare(token,"bold") == 0)
-              type_info->weight=700;
-            if (LocaleCompare(token,"normal") == 0)
-              type_info->weight=400;
+            ssize_t
+              weight;
+
+            weight=ParseCommandOption(MagickWeightOptions,MagickFalse,token);
+            if (weight == -1)
+              weight=StringToUnsignedLong(token);
+            type_info->weight=(size_t) weight;
             break;
           }
         break;
@@ -1336,7 +1324,7 @@ static MagickBooleanType LoadTypeCache(SplayTreeInfo *type_cache,
     }
   }
   token=(char *) RelinquishMagickMemory(token);
-  return(status);
+  return(status != 0 ? MagickTrue : MagickFalse);
 }
 
 /*
